{% extends "lfs/base.html" %}
{% load i18n %}

{% block section %}{% endblock %}
{% block left-slot-wrapper%}{% endblock %}
{% block right-slot-wrapper%}{% endblock %}

{% block breadcrumbs %}
    <ul class="breadcrumbs">
        <li>{% trans 'You are here:' %}</li>
        <li>
            <a href="{% url lfs_shop_view %}">
                {% trans 'Home' %}</a> &gt;
        </li>
        <li>
            {% trans 'Password reset successful' %}
        </li>
    </ul>    
{% endblock %}


{% block title %}{% trans 'Password reset successful' %}{% endblock %}

{% block content %}

<h1>{% trans 'Password reset successful' %}</h1>

<p>{% trans "We've e-mailed you instructions for setting your password to the e-mail address you submitted. You should be receiving it shortly." %}</p>

{% endblock %}
