<div id="shipping-address-inline">
    <table class="shipping-address">
        <tr>
            <td class="label">
                <label for="id_shipping_firstname">{{ form.shipping_firstname.label_tag }}:</label>
            </td>
            <td>
                {{ form.shipping_firstname.errors }}
                {{ form.shipping_firstname }}
            </td>
        </tr>
        <tr>
            <td class="label">
                <label for="id_shipping_lastname">{{ form.shipping_lastname.label_tag }}:</label>
            </td>
            <td>
                {{ form.shipping_lastname.errors }}
                {{ form.shipping_lastname }}
            </td>
        </tr>
        {{ address_form.as_table }}
        {% if request.user.is_anonymous %}
           <tr>
                <td class="label">
                    <label for="id_shipping_email">{{ form.shipping_email.label_tag }}:</label>
                </td>
                <td>
                    {{ form.shipping_email.errors }}
                    {{ form.shipping_email }}
                </td>
           </tr>
       {% endif %}
       {% if form.shipping_phone %}
            <tr>
                <td class="label">
                    <label for="id_shipping_country">{{ form.shipping_phone.label_tag }}:</label>
                </td>
                <td>
                    {{ form.shipping_phone.errors }}
                    {{ form.shipping_phone }}
                </td>
            </tr>
       {% endif %}
    </table>
</div>
