{% extends "lfs/base.html" %}
{% load i18n %}

{% block title %}{% trans "Password reset" %}{% endblock %}
{% block section %}{% endblock %}
{% block left-slot-wrapper%}{% endblock %}
{% block right-slot-wrapper%}{% endblock %}

{% block breadcrumbs %}
    <ul class="breadcrumbs">
        <li>{% trans 'You are here:' %}</li>
        <li>
            <a href="{% url lfs_shop_view %}">
                {% trans 'Home' %}</a> &gt;
        </li>
        <li>
            {% trans 'Password reset' %}
        </li>
    </ul>    
{% endblock %}

{% block content %}

    <h1>{% trans "Password reset" %}</h1>

    <p>{% trans "Enter your e-mail address below, and we'll e-mail instructions for setting a new one." %}</p>

    <form action="" 
          method="post">
        {{ form.email.errors }}
        <p>
            <label for="id_email">
                {% trans 'E-mail address:' %}
            </label> {{ form.email }} 
            <input type="submit" value="{% trans 'Reset my password' %}" />
        </p>
    </form>

{% endblock %}
